==> haskell-fgl-5.8.3.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl
version:              5.8.3.0
visibility:           public
id:                   fgl-5.8.3.0-GZ4l8hdJ4noD1bffNtTEn2
key:                  fgl-5.8.3.0-GZ4l8hdJ4noD1bffNtTEn2
license:              BSD-3-Clause
maintainer:           athas@sigkill.dk
author:               Martin Erwig, Ivan Lazar Miljenovic
synopsis:             Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.

    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.

category:             Data Structures, Graphs
abi:                  588d4c750d34344f3ac393616c9f3c89
exposed:              True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree

hidden-modules:       Paths_fgl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fgl-5.8.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fgl-5.8.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fgl-5.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl
hs-libraries:         HSfgl-5.8.3.0-GZ4l8hdJ4noD1bffNtTEn2
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html:         /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-5.8.3.0-101-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl
version:              5.8.3.0
visibility:           public
id:                   fgl-5.8.3.0-3MOLlmGRslHDwph4COHJsy
key:                  fgl-5.8.3.0-3MOLlmGRslHDwph4COHJsy
license:              BSD-3-Clause
maintainer:           athas@sigkill.dk
author:               Martin Erwig, Ivan Lazar Miljenovic
synopsis:             Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.

    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.

category:             Data Structures, Graphs
abi:                  31206980c7d8646f6eb58c777a269a51
exposed:              True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree

hidden-modules:       Paths_fgl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fgl-5.8.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fgl-5.8.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fgl-5.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl
hs-libraries:         HSfgl-5.8.3.0-3MOLlmGRslHDwph4COHJsy
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html:         /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
